package org.opengroup.osdu.notification.api;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import com.sun.jersey.api.client.ClientResponse;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import org.opengroup.osdu.notification.util.GCPTestUtils;

public class TestPubsubEndpointHMAC extends PubsubEndpointHMACTests {

  @BeforeClass
  public static void classSetup() throws Exception {
    PubsubEndpointHMACTests.classSetup();
  }

  @AfterClass
  public static void classTearDown() throws Exception {
  }

  @Before
  @Override
  public void setup() throws Exception {
    this.testUtils = new GCPTestUtils();
  }

  @After
  @Override
  public void tearDown() throws Exception {
    this.testUtils = null;
  }

  @Override
  @Test
  public void should_return20X_when_usingCredentialsWithOpsPermission() throws Exception {
    createResource();

    try {
      ClientResponse response = descriptor.run(getArg(), testUtils.getOpsToken());

      assertEquals(error(response.getStatus() == 204 ? "" : response.getEntity(String.class)),
          expectedOkResponseCode(), response.getStatus());
      assertEquals("GET, POST, PUT, DELETE, OPTIONS, HEAD, PATCH",
          response.getHeaders().getFirst("Access-Control-Allow-Methods"));
      assertEquals(
          "access-control-allow-origin, origin, content-type, accept, authorization, data-partition-id, correlation-id, appkey",
          response.getHeaders().getFirst("Access-Control-Allow-Headers"));
      assertEquals("*", response.getHeaders().getFirst("Access-Control-Allow-Origin"));
      assertEquals("true", response.getHeaders().getFirst("Access-Control-Allow-Credentials"));
      assertEquals("DENY", response.getHeaders().getFirst("X-Frame-Options"));
      assertEquals("1; mode=block", response.getHeaders().getFirst("X-XSS-Protection"));
      assertEquals("nosniff", response.getHeaders().getFirst("X-Content-Type-Options"));
      assertEquals("no-cache, no-store, must-revalidate",
          response.getHeaders().getFirst("Cache-Control"));
      assertEquals("default-src 'self'", response.getHeaders().getFirst("Content-Security-Policy"));
      assertTrue(response.getHeaders().get("Strict-Transport-Security").get(0)
          .contains("max-age=31536000"));
      assertTrue(response.getHeaders().get("Strict-Transport-Security").get(0)
          .contains("includeSubDomains"));
      assertEquals("0", response.getHeaders().getFirst("Expires"));
    } finally {
      deleteResource();
    }
  }
}